Keyboard shortcuts

Press or to navigate between chapters

Press S or / to search in the book

Press ? to show this help

Press Esc to hide this help

AccountValidityProof

Git Source

Proof of inclusion of an account in the accounts drive.

From the index and siblings, one can calculate the accounts drive root.

The siblings array should have size equal to the log2 of the maximum number of accounts.

struct AccountValidityProof {
uint64 accountIndex;
bytes32[] accountRootSiblings;
}

Properties

NameTypeDescription
accountIndexuint64Index of account in the accounts drive
accountRootSiblingsbytes32[]Siblings of the account root in the accounts drive