AccountValidityProof
Proof of inclusion of an account in the accounts drive.
From the index and siblings, one can calculate the accounts drive root.
The siblings array should have size equal to the log2 of the maximum number of accounts.
struct AccountValidityProof {
uint64 accountIndex;
bytes32[] accountRootSiblings;
}
Properties
| Name | Type | Description |
|---|---|---|
accountIndex | uint64 | Index of account in the accounts drive |
accountRootSiblings | bytes32[] | Siblings of the account root in the accounts drive |